#Installation



##Install from PyPI
<br>
`GR_F4C` is available on PyPI. To install `GR_F4C`, run this command in your terminal:

```sh
pip install GR_F4C
```
##Install from conda-forge

<br>
`GR_F4C` is also available on conda-forge. If you have Anaconda or Miniconda installed on your computer, you can create a conda Python environment to install `GR_F4C`:

```sh
conda install -c defaults -c conda-forge GR_F4C
```
##Install from GitHub

<br>
To install the development version from GitHub using Git, run the following command in your terminal:
```sh
```
##Colaboratory 

<br>
Colaboratory lets you connect to a local runtime using Jupyter. This allows you to execute code on your local hardware and have access to your local file system.

**Step 1: Install Jupyter**<br>
Install [Jupyter](https://jupyter.org/install) on your local machine.

**Step 2: Install and enable the jupyter_http_over_ws jupyter extension (one-off)** <br>
The ```jupyter_http_over_ws``` extension is authored by the Colaboratory team and available on [GitHub](https://github.com/googlecolab/jupyter_http_over_ws).

```sh
pip install jupyter_http_over_ws
jupyter serverextension enable --py jupyter_http_over_ws
```
**Step 3: Start server and authenticate**<br>
New notebook servers are started normally, though you will need to set a flag to explicitly trust WebSocket connections from the Colaboratory frontend.

```sh
jupyter notebook \
  --NotebookApp.allow_origin='https://colab.research.google.com' \
  --port=8888 \
  --NotebookApp.port_retries=0
```   
Once the server has started, it will print a message with the initial backend URL used for authentication. Make a copy of this URL as you'll need to provide this in the next step.

**Step 4: Connect to the local runtime**<br>
In Colaboratory, click the 'Connect' button and select 'Connect to local runtime…'. Enter the URL from the previous step in the dialogue that appears and click the 'Connect' button. After this, you should now be connected to your local runtime.

##Upgrade GR_F4C
<br>
If you have installed `GR_F4C` before and want to upgrade to the latest version, you can run the following command in your terminal:

```sh
pip install -U GR_F4C
```
If you use conda, you can update `GR_F4C` to the latest version by running the following command in your terminal:

```sh
conda update GR_F4C
```
